@@ -1,4 +1,4 @@
-/* $Id: file-open.c,v 1.5 2000/02/16 22:49:02 trow Exp $ */
+/* $Id: file-open.c,v 1.7 2000/04/13 19:45:18 trow Exp $ */
 
 /*
  * file-open.c
@@ -27,18 +27,26 @@
 #include <config.h>
 #include <gnome.h>
 
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+
 #include <guppi-data-tree.h>
 #include <guppi-file.h>
 #include <guppi-data-importer.h>
 #include <guppi-data-importer-plug-in.h>
 
 #include "file-open.h"
+#include "guppi-app.h"
 
 static void
 do_import(GuppiDataImporter* imp)
 {
   GuppiData** dv;
   gint i;
+  GuppiApp* app;
+  const gchar* filename = NULL;
+  gboolean activity=FALSE;
 
   dv = guppi_data_importer_import(imp);
   if (dv == NULL) {
@@ -50,7 +58,15 @@ do_import(GuppiDataImporter* imp)
   for (i=0; dv[i] != NULL; ++i) {
     guppi_data_tree_add(guppi_data_tree_main(), dv[i]);
     gtk_object_unref(GTK_OBJECT(dv[i]));
+    activity = TRUE;
   }
+  if (activity) {
+    app = GUPPI_APP(gtk_object_get_data(GTK_OBJECT(imp), "app"));
+    filename = guppi_data_importer_filename(imp);
+    if (filename)
+      guppi_app_add_recently_visited_file(app, filename);
+  }
+    
   g_free(dv);
   gtk_object_unref(GTK_OBJECT(imp));
 }
@@ -68,11 +84,12 @@ on_import_config_clicked(GnomeDialog* dialog, gint n, gpointer user_data)
 }
 
 static void
-do_import_config(GuppiDataImporterPlugIn* dipi, GuppiFile* file)
+do_import_config(GuppiDataImporterPlugIn* dipi, GuppiFile* file, GuppiApp* app)
 {
   GuppiDataImporter* imp;
   GtkWidget* imp_config;
   GtkWidget* dialog;
+  gchar* filename;
 
   g_return_if_fail(dipi != NULL);
   g_return_if_fail(file != NULL);
@@ -81,6 +98,15 @@ do_import_config(GuppiDataImporterPlugIn* dipi, GuppiFile* file)
   imp = (dipi->construct)();
   g_return_if_fail(imp != NULL);
 
+  gtk_object_set_data(GTK_OBJECT(imp), "app", app);
+
+  filename = g_strdup(guppi_file_filename(file));
+  if (filename) {
+    g_free(app->most_recent_open_directory);
+    *(g_filename_pointer(filename)) = '\0';
+    app->most_recent_open_directory = filename;
+  }
+
   guppi_data_importer_set_source(imp, file);
 
   imp_config = NULL;
@@ -109,6 +135,7 @@ do_import_config(GuppiDataImporterPlugIn* dipi, GuppiFile* file)
 struct import_gadget {
   GuppiFile* file;
   GuppiDataImporterPlugIn* selected_plug_in;
+  GuppiApp* app;
 };
 
 static void
@@ -128,21 +155,21 @@ on_plugin_select_dialog_clicked(GnomeDialog* dialog, gint n,
   GuppiFile* file = gadget->file;
   gtk_widget_destroy(GTK_WIDGET(dialog));
   if (n == 0 && dipi) 
-    do_import_config(dipi, file);
+    do_import_config(dipi, file, gadget->app);
   
 }
 
 static void
 on_plugin_select_dialog_close(GnomeDialog* dialog, gpointer gadget)
 {
-  g_message("freeing gadget");
   g_free(gadget);
 }
 
-static void
-ask_about_import_type(const gchar* filename,
-		      gboolean force_ask,
-		      double threshold)
+void
+file_open_ask_about_import_type(const gchar* filename,
+				gboolean force_ask,
+				double threshold,
+				GuppiApp* app)
 {
   GuppiFile* file;
   const gint buffer_size = 256;
@@ -182,7 +209,7 @@ ask_about_import_type(const gchar* filename,
   /* If only one plug-in seems possible, don't ask --- just use it. */
   if (g_list_next(assessment) == NULL) {
     impass = (GuppiDataImporterAssessment*)assessment->data;
-    do_import_config(impass->plug_in, file);
+    do_import_config(impass->plug_in, file, app);
     g_free(assessment->data);
     g_list_free(assessment);
     return;
@@ -196,6 +223,7 @@ ask_about_import_type(const gchar* filename,
   gadget = g_new(struct import_gadget, 1);
   gadget->file = file;
   gadget->selected_plug_in = NULL;
+  gadget->app = app;
 
   first_rb = rb = NULL;
   for (iter = assessment; iter != NULL; iter = g_list_next(iter)) {
@@ -246,23 +274,50 @@ ask_about_import_type(const gchar* filename,
 
 /****************************************************************************/
 
+
 static void
 on_file_ok_clicked(GtkButton* b, GtkFileSelection* fs)
 {
   gchar* filename;
+  struct stat buf;
+  GuppiApp* app;
+
+  filename = gtk_file_selection_get_filename(fs);
   
-  filename = g_strdup(gtk_file_selection_get_filename(fs));
-  gtk_widget_destroy(GTK_WIDGET(fs));
-  ask_about_import_type(filename, FALSE, 0);
-  g_free(filename);
+  if (stat(filename, &buf)) {
+    filename = g_strdup_printf(_("Unknown file: %s"), filename);
+    gtk_widget_show_all(gnome_warning_dialog(filename));
+    g_free(filename);
+    gtk_widget_destroy(GTK_WIDGET(fs));
+  } else if (S_ISDIR(buf.st_mode)) {
+    filename = g_strdup_printf("%s/", filename);
+    gtk_file_selection_set_filename(fs, filename);
+    g_free(filename);
+  } else {
+    app = GUPPI_APP(gtk_object_get_data(GTK_OBJECT(fs), "app"));
+    filename = g_strdup(filename);
+    gtk_widget_destroy(GTK_WIDGET(fs));
+    file_open_ask_about_import_type(filename, FALSE,
+				    DEFAULT_FILE_OPEN_THRESHOLD,
+				    app);
+
+    g_free(filename);
+  }
 }
 
 void
-file_open(void)
+file_open(GtkWidget* w, GuppiApp* app)
 {
   GtkWidget* file_selector;
 
   file_selector = gtk_file_selection_new(_("Select File To Open"));
+  gtk_object_set_data(GTK_OBJECT(file_selector), "app", app);
+
+  gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(file_selector));
+
+  if (app->most_recent_open_directory)
+    gtk_file_selection_set_filename(GTK_FILE_SELECTION(file_selector),
+				    app->most_recent_open_directory);
 
   gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(file_selector)->ok_button),
 		     "clicked",
@@ -277,4 +332,4 @@ file_open(void)
   gtk_widget_show_all(GTK_WIDGET(file_selector));
 }
 
-/* $Id: file-open.c,v 1.5 2000/02/16 22:49:02 trow Exp $ */
+/* $Id: file-open.c,v 1.7 2000/04/13 19:45:18 trow Exp $ */
