@@ -1,12 +1,12 @@
 /* This is -*- C -*- */
-/* $Id: guppi-alpha-template.c,v 1.1 2000/02/28 04:57:33 trow Exp $ */
+/* $Id: guppi-alpha-template.c,v 1.4 2000/04/13 19:45:20 trow Exp $ */
 
 /*
  * guppi-alpha-template.c
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
  *
- * Developed by Jon Trowbridge <trow@emccta.com> and
+ * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
  *
  * This program is free software; you can redistribute it and/or
@@ -29,6 +29,16 @@
 #include <guppi-rgb.h>
 #include "guppi-alpha-template.h"
 
+#include <libart_lgpl/art_rect.h>
+#include <libart_lgpl/art_vpath.h>
+#include <libart_lgpl/art_bpath.h>
+#include <libart_lgpl/art_vpath_bpath.h>
+#include <libart_lgpl/art_vpath_dash.h>
+#include <libart_lgpl/art_svp.h>
+#include <libart_lgpl/art_svp_vpath.h>
+#include <libart_lgpl/art_svp_wind.h>
+#include <libart_lgpl/art_svp_point.h>
+
 static GtkObjectClass* parent_class = NULL;
 
 enum {
@@ -353,8 +363,8 @@ guppi_alpha_template_new_circle(double radius)
   }
   if (CIRCLE_MIN <= radius && radius <= CIRCLE_MAX) {
     buffer_i = (radius - CIRCLE_MIN)/CIRCLE_STEP;
-    if (buffer[buffer_i])
-      return buffer[buffer_i];
+    if ( (atemp = buffer[buffer_i]) )
+      return atemp;
   }
 
   cent = span/2.0;
@@ -741,10 +751,226 @@ guppi_alpha_template_new_box(double radius, double theta)
   return atemp;
 }
 
+/****************************************************************************/
+
+/*** unexposed gnome-print stuff ***/
+
+typedef struct {
+  int       ch;
+  ArtBpath *bpath;
+  ArtDRect  bbox;
+  double    wx;
+} Gt1GlyphOutline;
+
+typedef int Gt1NameId;
+
+typedef struct {
+  gpointer psc;
+  gpointer fi;
+  gpointer mfi;
+  gpointer fontdict;
+  Gt1NameId* encoding;
+  Gt1NameId id_charstrings;
+  GHashTable *glyph_outlines;
+} Gt1LoadedFont;
+
+
+Gt1LoadedFont * gt1_load_font (const char *filename);
+void gt1_unload_font (Gt1LoadedFont *);
+
+Gt1GlyphOutline *gt1_glyph_outline_lookup (Gt1LoadedFont *, int glyphnum);
+ArtBpath *gt1_get_glyph_outline (Gt1LoadedFont *font, int glyphnum,
+				 double *p_wx);
+
+void art_drect_bpath (ArtDRect *bbox, const ArtBpath *bpath);
+
+
+static Gt1GlyphOutline*
+my_gt1_glyph_outline_lookup (Gt1LoadedFont* font, int c)
+{
+  static GHashTable* outline_hash = NULL;
+  GHashTable* font_hash;
+  Gt1GlyphOutline* go;
+
+  /*
+    To support older versions of gnome-print, we don't use the
+    glyph_outlines hash inside of the Gt1LoadedFont struct.
+
+    Instead, we define a hash for each font, keyed off of the address of
+    the font structure.  (So if we have many copies of the same font,
+    we will get redundant glyph outlines.  Yet another reason not to have
+    many copies of the same font...)
+  */
+
+  if (outline_hash == NULL)
+    outline_hash = g_hash_table_new(NULL, NULL);
+
+  font_hash = g_hash_table_lookup(outline_hash, font);
+  if (font_hash == NULL) {
+    font_hash = g_hash_table_new(NULL, NULL);
+    g_hash_table_insert(outline_hash, font, font_hash);
+  }
+
+  go = (Gt1GlyphOutline*)g_hash_table_lookup(font_hash,
+					     GINT_TO_POINTER(c));
+  if (go == NULL) {
+
+    go = g_new (Gt1GlyphOutline, 1);
+    go->ch = c;
+    go->bpath = gt1_get_glyph_outline (font, c, &go->wx);
+    art_drect_bpath (&go->bbox, go->bpath);
+
+    g_hash_table_insert(font_hash, GINT_TO_POINTER(c), go);
+
+  }
+
+  return go;
+}
+
+static Gt1LoadedFont*
+get_gt1_font(GnomeFont* font)
+{
+  static GHashTable* gt1_hash = NULL;
+  Gt1LoadedFont* gt1_font;
+
+  g_return_val_if_fail(font != NULL, NULL);
+
+  if (gt1_hash == NULL) 
+    gt1_hash = g_hash_table_new(g_str_hash, g_str_equal);
+
+  gt1_font = (Gt1LoadedFont*)g_hash_table_lookup(gt1_hash,
+						 font->fontmap_entry->pfb_fn);
+
+  if (gt1_font == NULL) {
+
+    gt1_font = gt1_load_font(font->fontmap_entry->pfb_fn);
+
+    g_hash_table_insert(gt1_hash,
+			font->fontmap_entry->pfb_fn,
+			(gpointer)gt1_font);
+    
+  }
+
+  return gt1_font;
+}
+
+/****************************************************************************/
+
+GuppiAlphaTemplate*
+guppi_alpha_template_text_general(GnomeFont* font, double size,
+				  const gchar* text,
+				  double angle,
+				  gboolean filled,
+				  double outline_width)
+{
+  Gt1LoadedFont* gt1_font;
+  Gt1GlyphOutline* glyph;
+  gint w, h;
+  ArtIRect bbox, wbi;
+  ArtDRect w_bbox;
+  double affine[6];
+  double rot[6];
+  GnomeCanvasBuf* buf;
+  GuppiAlphaTemplate* atemp;
+  guchar* p;
+  ArtBpath* bpath;
+  ArtVpath* vpath;
+  ArtSVP* svp;
+  gint i,j;
+
+  g_return_val_if_fail(font != NULL, NULL);
+  g_return_val_if_fail(size > 0, NULL);
+  g_return_val_if_fail(text != NULL, NULL);
+
+  gt1_font = get_gt1_font(font);
+  g_return_val_if_fail(gt1_font != NULL, NULL);
+
+  /* First, compute bounding box for the text */
+
+  art_affine_scale(affine, size * 0.001, size * -0.001);
+  art_affine_rotate(rot, angle);
+  art_affine_multiply(affine, affine, rot);
+
+  for (i=0; text[i]; ++i) {
+    glyph = my_gt1_glyph_outline_lookup(gt1_font, text[i]);
+    art_drect_affine_transform(&w_bbox, &glyph->bbox, affine);
+    art_drect_to_irect(&wbi, &w_bbox);
+    if (i==0)
+      bbox = wbi;
+    else
+      art_irect_union(&bbox, &bbox, &wbi);
+    affine[4] += glyph->wx * affine[0];
+    affine[5] += glyph->wx * affine[1];
+  }
+
+  w = bbox.x1 - bbox.x0;
+  h = bbox.y1 - bbox.y0;
+
+  /* Next, create a buffer to render the text into */
+  buf = g_new0(GnomeCanvasBuf, 1);
+  buf->buf = g_new0(guchar, w*h*3);
+  buf->buf_rowstride = w*3;
+  buf->rect = bbox;
+  buf->bg_color = 0;
+  buf->is_bg = TRUE;
+  buf->is_buf = FALSE;
+
+  /* Punch the text info our buffer */
+  
+  art_affine_scale(affine, size * 0.001, size * -0.001);
+  art_affine_rotate(rot, angle);
+  art_affine_multiply(affine, affine, rot);
+
+  if (outline_width < 0.5)
+    outline_width = 0.5;
+
+  for (i=0; text[i]; ++i) {
+
+    glyph = my_gt1_glyph_outline_lookup(gt1_font, text[i]);
+    bpath = art_bpath_affine_transform(glyph->bpath, affine);
+    vpath = art_bez_path_to_vec(bpath, 0.25);
+    art_free(bpath);
+
+    if (filled) {
+      svp = art_svp_from_vpath(vpath);
+    } else {
+      svp = art_svp_vpath_stroke(vpath,
+				 gnome_canvas_join_gdk_to_art(GDK_JOIN_MITER),
+				 gnome_canvas_cap_gdk_to_art(GDK_CAP_BUTT),
+				 outline_width,
+				 4,
+				 0.25);
+    }
+
+    gnome_canvas_render_svp(buf, svp, 0xffffffff);
+    art_svp_free(svp);
+
+    art_free(vpath);
+
+    affine[4] += glyph->wx * affine[0];
+    affine[5] += glyph->wx * affine[1];
+  }
+
+  /* Copy our buffer into an alpha template object */
+  atemp = guppi_alpha_template_new(w,h);
+  p = buf->buf;
+  for (j=0; j<h; ++j) {
+    for (i=0; i<w; ++i) {
+      guppi_alpha_template_set_unsafe(atemp, i, j, *p);
+      p += 3;
+    }
+  }
+
+  /* Free our buffer */
+  g_free(buf->buf);
+  g_free(buf);
+
+  return atemp;
+}
 
 
 
 
 
 
-/* $Id: guppi-alpha-template.c,v 1.1 2000/02/28 04:57:33 trow Exp $ */
+/* $Id: guppi-alpha-template.c,v 1.4 2000/04/13 19:45:20 trow Exp $ */
