@@ -1,4 +1,4 @@
-/* $Id: guppi-canvas-item.c,v 1.13 2000/03/09 22:55:47 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.15 2000/04/13 19:45:20 trow Exp $ */
 
 /*
  * guppi-canvas-item.c
@@ -542,10 +542,12 @@ renegotiate_x_start(GuppiCanvasItem* gci)
 {
   if (gci->reneg_x_started)
     return;
+  
   gci->full_x0 = gci->bb_x0;
   gci->full_x1 = gci->bb_x1;
   gci->reneg_x_started = TRUE;
   gtk_signal_emit(GTK_OBJECT(gci), gci_signals[RENEGOTIATE_X_START]);
+  gci->reneg_x_started = FALSE;
   if (!gci->bb_passive)
     gtk_signal_emit(GTK_OBJECT(gci), gci_signals[RENEGOTIATE_X_DECLARE],
 		    gci->full_x0, gci->full_x1);
@@ -562,19 +564,15 @@ renegotiate_x_accept(GuppiCanvasItem* src, double x0, double x1,
     m1 = x1;
   } else {
     m0 = MIN(gci->full_x0, x0);
-    m1 = MIN(gci->full_x1, x1);
+    m1 = MAX(gci->full_x1, x1);
   }
 
-  /* This flag needs to get reset somewhere, after all of the _start
-     functions are finished. */
-  gci->reneg_x_started = FALSE; 
-
   if (gci->full_x0 == m0 && gci->full_x1 == m1)
     return;
   
   gci->full_x0 = m0;
   gci->full_x1 = m1;
-  
+
   /* If anything changed, we re-declare */
   gtk_signal_emit(GTK_OBJECT(gci), gci_signals[RENEGOTIATE_X_DECLARE],
 		  gci->full_x0, gci->full_x1);
@@ -590,8 +588,8 @@ renegotiate_y_start(GuppiCanvasItem* gci)
   gci->full_y0 = gci->bb_y0;
   gci->full_y1 = gci->bb_y1;
   gci->reneg_y_started = TRUE;
-
   gtk_signal_emit(GTK_OBJECT(gci), gci_signals[RENEGOTIATE_Y_START]);
+  gci->reneg_y_started = FALSE;
   if (!gci->bb_passive)
     gtk_signal_emit(GTK_OBJECT(gci), gci_signals[RENEGOTIATE_Y_DECLARE],
 		    gci->full_y0, gci->full_y1);
@@ -608,13 +606,9 @@ renegotiate_y_accept(GuppiCanvasItem* src, double y0, double y1,
     m1 = y1;
   } else {
     m0 = MIN(gci->full_y0, y0);
-    m1 = MIN(gci->full_y1, y1);
+    m1 = MAX(gci->full_y1, y1);
   }
 
-  /* This flag needs to get reset somewhere, after all of the _start
-     functions are finished. */
-  gci->reneg_y_started = FALSE; 
-
   if (gci->full_y0 == m0 && gci->full_y1 == m1)
     return;
 
@@ -630,6 +624,45 @@ renegotiate_y_accept(GuppiCanvasItem* src, double y0, double y1,
 
 /*****************************************************************************/
 
+void
+guppi_canvas_item_set_x_world(GuppiCanvasItem* gci, double x0, double x1)
+{
+  g_return_if_fail(gci != NULL);
+
+  if (gci->wx0 == x0 && gci->wx1 == x1)
+    return;
+
+  gci->wx0 = x0;
+  gci->wx1 = x1;
+
+  guppi_canvas_item_request_update(gci);
+}
+
+void
+guppi_canvas_item_set_y_world(GuppiCanvasItem* gci, double y0, double y1)
+{
+  g_return_if_fail(gci != NULL);
+
+  if (gci->wy0 == y0 && gci->wy1 == y1)
+    return;
+
+  gci->wy0 = y0;
+  gci->wy1 = y1;
+
+  guppi_canvas_item_request_update(gci);
+}
+
+void
+guppi_canvas_item_set_world(GuppiCanvasItem* gci,
+			    double x0, double y0, double x1, double y1)
+{
+  g_return_if_fail(gci != NULL);
+  guppi_canvas_item_set_x_world(gci, x0, x1);
+  guppi_canvas_item_set_y_world(gci, y0, y1);
+}
+
+/*****************************************************************************/
+
 void
 guppi_canvas_item_set_x_bounds(GuppiCanvasItem* gci, double x0, double x1)
 {
@@ -924,6 +957,6 @@ guppi_canvas_item_disconnect(GuppiCanvasItem* a, GuppiCanvasItem* b)
 
 }
 
-/* $Id: guppi-canvas-item.c,v 1.13 2000/03/09 22:55:47 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.15 2000/04/13 19:45:20 trow Exp $ */
 
 
