@@ -1,12 +1,12 @@
 /* This is -*- C -*- */
-/* $Id: guppi-canvas-item.h,v 1.10 2000/03/09 22:55:48 trow Exp $ */
+/* $Id: guppi-canvas-item.h,v 1.11 2000/04/13 19:45:20 trow Exp $ */
 
 /*
  * guppi-canvas-item.h
  *
  * Copyright (C) 1999 EMC Capital Management, Inc.
  *
- * Developed by Jon Trowbridge <trow@emccta.com> and
+ * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
  *
  * This program is free software; you can redistribute it and/or
@@ -102,6 +102,12 @@ GtkType guppi_canvas_item_get_type(void);
 GuppiItemState* guppi_canvas_item_state(GuppiCanvasItem*);
 void guppi_canvas_item_set_state(GuppiCanvasItem*, GuppiItemState*);
 
+void guppi_canvas_item_set_x_world(GuppiCanvasItem*, double x0, double x1);
+void guppi_canvas_item_set_y_world(GuppiCanvasItem*, double y0, double y1);
+void guppi_canvas_item_set_world(GuppiCanvasItem*,
+				 double x0, double y0,
+				 double x1, double y1);
+
 void guppi_canvas_item_set_x_bounds(GuppiCanvasItem*, double x0, double x1);
 void guppi_canvas_item_set_y_bounds(GuppiCanvasItem*, double y0, double y1);
 void guppi_canvas_item_set_bounds(GuppiCanvasItem*,
@@ -156,4 +162,4 @@ void guppi_canvas_item_disconnect(GuppiCanvasItem*, GuppiCanvasItem*);
 
 #endif /* _INC_GUPPI_CANVAS_ITEM_H */
 
-/* $Id: guppi-canvas-item.h,v 1.10 2000/03/09 22:55:48 trow Exp $ */
+/* $Id: guppi-canvas-item.h,v 1.11 2000/04/13 19:45:20 trow Exp $ */
