@@ -1,12 +1,12 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plot-element.c,v 1.8 2000/03/10 16:30:39 trow Exp $ */
+/* $Id: guppi-plot-element.c,v 1.10 2000/04/13 19:45:20 trow Exp $ */
 
 /*
  * guppi-plot-element.c
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
  *
- * Developed by Jon Trowbridge <trow@emccta.com> and
+ * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
  *
  * This program is free software; you can redistribute it and/or
@@ -333,9 +333,8 @@ event_dispatcher(GuppiCanvasItem* gci, GdkEvent* ev, GuppiPlotElement* elem)
     return tool != NULL;
 
   } else if (ev->type == GDK_BUTTON_RELEASE && tool != NULL) {
-
+    
     if (tool->cue_item) {
-      gnome_canvas_item_hide(tool->cue_item);
       gtk_object_destroy(GTK_OBJECT(tool->cue_item));
       tool->cue_item = NULL;
     }
@@ -411,6 +410,23 @@ event_dispatcher(GuppiCanvasItem* gci, GdkEvent* ev, GuppiPlotElement* elem)
   return FALSE;
 }
 
+static void
+resize_cb(GtkWidget* w, GtkAllocation* al, GuppiCanvasItem* gci)
+{
+  double x0, y0, x1, y1;
+
+  /* Get the bounding world coordinates of the entire visible piece of
+     the canvas. */
+  gnome_canvas_window_to_world(GNOME_CANVAS_ITEM(gci)->canvas,
+			       0, 0, &x0, &y0);
+  gnome_canvas_window_to_world(GNOME_CANVAS_ITEM(gci)->canvas,
+			       al->width, al->height, &x1, &y1);
+
+  /* Set our item's world so as to fill up that world.  This is a hack
+     in place of real geometry management. */
+  guppi_canvas_item_set_world(gci, x0, y0, x1, y1);
+}
+
 GuppiCanvasItem*
 guppi_plot_element_make_canvas_item(GuppiPlotElement* gpe,
 				    GnomeCanvas* canv,
@@ -431,6 +447,11 @@ guppi_plot_element_make_canvas_item(GuppiPlotElement* gpe,
 
   gci = fn(gpe, canv, x1, y1, x2, y2);
 
+  gtk_signal_connect(GTK_OBJECT(canv),
+		     "size_allocate",
+		     GTK_SIGNAL_FUNC(resize_cb),
+		     gci);
+
   gtk_signal_connect(GTK_OBJECT(gci),
 		     "event",
 		     GTK_SIGNAL_FUNC(event_dispatcher),
@@ -549,4 +570,4 @@ guppi_plot_element_edit(GuppiPlotElement* gpe)
 
 
 
-/* $Id: guppi-plot-element.c,v 1.8 2000/03/10 16:30:39 trow Exp $ */
+/* $Id: guppi-plot-element.c,v 1.10 2000/04/13 19:45:20 trow Exp $ */
