@@ -1,12 +1,12 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plug-in.c,v 1.4 2000/03/05 23:44:21 trow Exp $ */
+/* $Id: guppi-plug-in.c,v 1.7 2000/04/14 14:56:00 trow Exp $ */
 
 /*
  * guppi-plug-in.c
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
  *
- * Developed by Jon Trowbridge <trow@emccta.com> and
+ * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
  *
  * This program is free software; you can redistribute it and/or
@@ -174,8 +174,8 @@ register_plug_in(GuppiPlugIn* info)
       /* The already-loaded version is older */
       g_message("Replacing %s %d.%d.%d with %d.%d.%d",
                 info->internal_name,
-                info->major_version, info->micro_version, info->micro_version,
-                ai->major_version, ai->micro_version, ai->micro_version);
+                info->major_version, info->minor_version, info->micro_version,
+                ai->major_version, ai->minor_version, ai->micro_version);
 
       g_hash_table_remove(type_table, info->internal_name);
       
@@ -184,7 +184,7 @@ register_plug_in(GuppiPlugIn* info)
 
       g_message("Skipping %s %d.%d.%d",
                 info->internal_name,
-                info->major_version, info->micro_version, info->micro_version);
+                info->major_version, info->minor_version, info->micro_version);
       return;
     }
   }
@@ -297,7 +297,8 @@ guppi_plug_in_load_dir(const gchar* path_orig, gboolean recursive)
 
   dir = opendir(path);
   if (dir == NULL) {
-    g_message("Couldn't load plug-ins from %s", path);
+    /* If there is no such directory, just silently fail. */
+    /* g_message("Couldn't load plug-ins from %s", path);*/
     return;
   }
 
@@ -389,4 +390,4 @@ guppi_plug_in_foreach_of_type(const gchar* type,
 }
 
 
-/* $Id: guppi-plug-in.c,v 1.4 2000/03/05 23:44:21 trow Exp $ */
+/* $Id: guppi-plug-in.c,v 1.7 2000/04/14 14:56:00 trow Exp $ */
